==> huaweicloudsdkorganizations-3.1.123-py2.py3-none-any.whl: huaweicloudsdkorganizations/v1/model/move_account_req_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class MoveAccountReqBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'source_parent_id': 'str',
        'destination_parent_id': 'str'
    }

    attribute_map = {
        'source_parent_id': 'source_parent_id',
        'destination_parent_id': 'destination_parent_id'
    }

    def __init__(self, source_parent_id=None, destination_parent_id=None):
        """MoveAccountReqBody

        The model defined in huaweicloud sdk

        :param source_parent_id: 要移出账号的根或组织单元的唯一标识符（ID）。
        :type source_parent_id: str
        :param destination_parent_id: 要移入账号的根或组织单元的唯一标识符（ID）。
        :type destination_parent_id: str
        """
        
        

        self._source_parent_id = None
        self._destination_parent_id = None
        self.discriminator = None

        self.source_parent_id = source_parent_id
        self.destination_parent_id = destination_parent_id

    @property
    def source_parent_id(self):
        """Gets the source_parent_id of this MoveAccountReqBody.

        要移出账号的根或组织单元的唯一标识符（ID）。

        :return: The source_parent_id of this MoveAccountReqBody.
        :rtype: str
        """
        return self._source_parent_id

    @source_parent_id.setter
    def source_parent_id(self, source_parent_id):
        """Sets the source_parent_id of this MoveAccountReqBody.

        要移出账号的根或组织单元的唯一标识符（ID）。

        :param source_parent_id: The source_parent_id of this MoveAccountReqBody.
        :type source_parent_id: str
        """
        self._source_parent_id = source_parent_id

    @property
    def destination_parent_id(self):
        """Gets the destination_parent_id of this MoveAccountReqBody.

        要移入账号的根或组织单元的唯一标识符（ID）。

        :return: The destination_parent_id of this MoveAccountReqBody.
        :rtype: str
        """
        return self._destination_parent_id

    @destination_parent_id.setter
    def destination_parent_id(self, destination_parent_id):
        """Sets the destination_parent_id of this MoveAccountReqBody.

        要移入账号的根或组织单元的唯一标识符（ID）。

        :param destination_parent_id: The destination_parent_id of this MoveAccountReqBody.
        :type destination_parent_id: str
        """
        self._destination_parent_id = destination_parent_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MoveAccountReqBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkorganizations-3.1.148-py2.py3-none-any.whl: huaweicloudsdkorganizations/v1/model/move_account_req_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class MoveAccountReqBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'source_parent_id': 'str',
        'destination_parent_id': 'str'
    }

    attribute_map = {
        'source_parent_id': 'source_parent_id',
        'destination_parent_id': 'destination_parent_id'
    }

    def __init__(self, source_parent_id=None, destination_parent_id=None):
        r"""MoveAccountReqBody

        The model defined in huaweicloud sdk

        :param source_parent_id: 要移出账号的根或组织单元的唯一标识符（ID）。
        :type source_parent_id: str
        :param destination_parent_id: 要移入账号的根或组织单元的唯一标识符（ID）。
        :type destination_parent_id: str
        """
        
        

        self._source_parent_id = None
        self._destination_parent_id = None
        self.discriminator = None

        self.source_parent_id = source_parent_id
        self.destination_parent_id = destination_parent_id

    @property
    def source_parent_id(self):
        r"""Gets the source_parent_id of this MoveAccountReqBody.

        要移出账号的根或组织单元的唯一标识符（ID）。

        :return: The source_parent_id of this MoveAccountReqBody.
        :rtype: str
        """
        return self._source_parent_id

    @source_parent_id.setter
    def source_parent_id(self, source_parent_id):
        r"""Sets the source_parent_id of this MoveAccountReqBody.

        要移出账号的根或组织单元的唯一标识符（ID）。

        :param source_parent_id: The source_parent_id of this MoveAccountReqBody.
        :type source_parent_id: str
        """
        self._source_parent_id = source_parent_id

    @property
    def destination_parent_id(self):
        r"""Gets the destination_parent_id of this MoveAccountReqBody.

        要移入账号的根或组织单元的唯一标识符（ID）。

        :return: The destination_parent_id of this MoveAccountReqBody.
        :rtype: str
        """
        return self._destination_parent_id

    @destination_parent_id.setter
    def destination_parent_id(self, destination_parent_id):
        r"""Sets the destination_parent_id of this MoveAccountReqBody.

        要移入账号的根或组织单元的唯一标识符（ID）。

        :param destination_parent_id: The destination_parent_id of this MoveAccountReqBody.
        :type destination_parent_id: str
        """
        self._destination_parent_id = destination_parent_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MoveAccountReqBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
